@@ -52,6 +52,7 @@ import shutil
 import stat
 import sys
 import tempfile
+import urllib.parse
 from collections import defaultdict, deque
 from operator import methodcaller
 from typing import (
@@ -65,6 +66,7 @@ from typing import (
 		List,
 		Optional,
 		Sequence,
+		Type,
 		TypeVar,
 		Union
 		)
@@ -113,11 +115,12 @@ _PP = TypeVar("_PP", bound="PathPlus")
 .. versionadded:: 2.3.0
 """
 
-unwanted_dirs = (".git", "venv", ".venv", ".mypy_cache", "__pycache__", ".pytest_cache", ".tox", ".tox4")
+unwanted_dirs = (".git", ".hg", "venv", ".venv", ".mypy_cache", "__pycache__", ".pytest_cache", ".tox", ".tox4")
 """
 A list of directories which will likely be unwanted when searching directory trees for files.
 
 .. versionadded:: 2.3.0
+.. versionchanged:: 2.9.0  Added ``.hg`` (`mercurial <https://www.mercurial-scm.org>`_)
 """
 
 
@@ -316,7 +319,7 @@ def make_executable(filename: PathLike) -> None:
 	"""
 	Make the given file executable.
 
-	:param filename: Filename of the file to make executable
+	:param filename:
 	"""
 
 	if not isinstance(filename, pathlib.Path):
@@ -663,7 +666,7 @@ class PathPlus(pathlib.Path):
 				**kwargs,
 				)
 
-	if sys.version_info < (3, 10):  # pragma: no cover (<py310)
+	if sys.version_info < (3, 10):  # pragma: no cover (py310+)
 
 		def is_mount(self) -> bool:
 			"""
@@ -690,7 +693,7 @@ class PathPlus(pathlib.Path):
 			parent_ino = self.parent.stat().st_ino
 			return ino == parent_ino
 
-	if sys.version_info < (3, 8):  # pragma: no cover (<py38)
+	if sys.version_info < (3, 8):  # pragma: no cover (py38+)
 
 		def rename(self: _P, target: Union[str, pathlib.PurePath]) -> _P:  # type: ignore
 			"""
@@ -748,7 +751,7 @@ class PathPlus(pathlib.Path):
 				if not missing_ok:
 					raise
 
-	if sys.version_info < (3, 9):  # pragma: no cover (<py39)
+	if sys.version_info < (3, 9):  # pragma: no cover (py39+)
 
 		def __enter__(self):
 			return self
@@ -832,6 +835,42 @@ class PathPlus(pathlib.Path):
 			if file.is_dir():
 				yield from file.iterchildren(exclude_dirs, match)
 
+	@classmethod
+	def from_uri(cls: Type[_PP], uri: str) -> _PP:
+		"""
+		Construct a :class:`~.PathPlus` from a ``file`` URI returned by :meth:`pathlib.PurePath.as_uri`.
+
+		.. versionadded:: 2.9.0
+
+		:param uri:
+		"""
+
+		parseresult = urllib.parse.urlparse(uri)
+
+		if parseresult.scheme != "file":
+			raise ValueError(f"Unsupported URI scheme {parseresult.scheme!r}")
+		if parseresult.params or parseresult.query or parseresult.fragment:
+			raise ValueError("Malformed file URI")
+
+		if sys.platform == "win32":  # pragma: no cover (!Windows)
+
+			if parseresult.netloc:
+				path = ''.join([
+						"//",
+						urllib.parse.unquote_to_bytes(parseresult.netloc).decode("UTF-8"),
+						urllib.parse.unquote_to_bytes(parseresult.path).decode("UTF-8"),
+						])
+			else:
+				path = urllib.parse.unquote_to_bytes(parseresult.path).decode("UTF-8").lstrip('/')
+
+		else:  # pragma: no cover (Windows)
+			if parseresult.netloc:
+				raise ValueError("Malformed file URI")
+
+			path = urllib.parse.unquote_to_bytes(parseresult.path).decode("UTF-8")
+
+		return cls(path)
+
 
 class PosixPathPlus(PathPlus, pathlib.PurePosixPath):
 	"""
@@ -903,7 +942,7 @@ def traverse_to_file(base_directory: _P, *filename: PathLike, height: int = -1)
 	raise FileNotFoundError(f"'{filename[0]!s}' not found in {base_directory}")
 
 
-def matchglob(filename: PathLike, pattern: str, matchcase: bool = True):
+def matchglob(filename: PathLike, pattern: str, matchcase: bool = True) -> bool:
 	"""
 	Given a filename and a glob pattern, return whether the filename matches the glob.
 
@@ -1030,9 +1069,9 @@ def sort_paths(*paths: PathLike) -> List[PathPlus]:
 	"""
 	Sort the ``paths`` by directory, then by file.
 
-	:param paths:
-
 	.. versionadded:: 2.6.0
+
+	:param paths:
 	"""
 
 	directories: Dict[str, List[PathPlus]] = defaultdict(list)
@@ -1122,7 +1161,7 @@ class DirComparator(filecmp.dircmp):
 	methodmap = _methodmap  # type: ignore
 
 
-def compare_dirs(a: PathLike, b: PathLike):
+def compare_dirs(a: PathLike, b: PathLike) -> bool:
 	"""
 	Compare the content of two directory trees.
 
